]> granicus.if.org Git - curl/commitdiff
spelling fixes
authorViktor Szakats <vszakats@users.noreply.github.com>
Fri, 23 Feb 2018 23:29:01 +0000 (23:29 +0000)
committerViktor Szakats <vszakats@users.noreply.github.com>
Fri, 23 Feb 2018 23:29:01 +0000 (23:29 +0000)
Detected using the `codespell` tool.

Also contains one URL protocol upgrade.

Closes https://github.com/curl/curl/pull/2334

32 files changed:
CMake/Utilities.cmake
docs/BINDINGS.md
docs/FAQ
docs/MAIL-ETIQUETTE
docs/cmdline-opts/progress-bar.d
docs/examples/ftpupload.c
docs/libcurl/libcurl-tutorial.3
docs/libcurl/opts/CURLINFO_CONDITION_UNMET.3
include/curl/multi.h
lib/checksrc.pl
lib/curl_ntlm_wb.c
lib/ftp.c
lib/mk-ca-bundle.vbs
lib/objnames.inc
lib/parsedate.c
lib/rtsp.c
lib/sendf.c
lib/sha256.c
lib/telnet.c
lib/url.c
lib/urldata.h
packages/OS400/README.OS400
packages/vms/config_h.com
src/Makefile.netware
tests/ftpserver.pl
tests/libtest/lib560.c
tests/libtest/mk-lib1521.pl
tests/nroff-scan.pl
tests/pathhelp.pm
tests/server/CMakeLists.txt
tests/server/sockfilt.c
tests/server/sws.c

index 8b6276df611c78cf9292315e85e2c3eb586b38e3..005b166ff918c8b54e66a41b9ee2b5e823812f1f 100644 (file)
@@ -19,7 +19,7 @@ function(LIST_SPACES_APPEND_ONCE LIST_NAME)
   set(${LIST_NAME} "${NEW_LIST_SPACE}" PARENT_SCOPE)
 endfunction()
 
-# Convinience function that does the same as LIST(FIND ...) but with a TRUE/FALSE return value.
+# Convenience function that does the same as LIST(FIND ...) but with a TRUE/FALSE return value.
 # Ex: IN_STR_LIST(MY_LIST "Searched item" WAS_FOUND)
 function(IN_STR_LIST LIST_NAME ITEM_SEARCHED RETVAL)
   list(FIND ${LIST_NAME} ${ITEM_SEARCHED} FIND_POS)
index 3ee8599d42b10e94c2ebac4f4126e535709ef7c8..024f169e3e7f565a4265f2618bd09014a2238714 100644 (file)
@@ -95,7 +95,7 @@ Ruby: [curb](https://github.com/taf2/curb) written by Ross Bamford
 
 [Scilab](https://help.scilab.org/docs/current/fr_FR/getURL.html) binding by Sylvestre Ledru
 
-[S-Lang](http://www.jedsoft.org/slang/modules/curl.html) by John E Davis
+[S-Lang](https://www.jedsoft.org/slang/modules/curl.html) by John E Davis
 
 [Smalltalk](http://www.squeaksource.com/CurlPlugin/) Written by Danil Osipchuk
 
index 7ed5fa0ce0f8724d0d9e675eccb708b6dd6678ca..4dfd1642142677987b9359972c6d07e41c8876f2 100644 (file)
--- a/docs/FAQ
+++ b/docs/FAQ
@@ -218,9 +218,9 @@ FAQ
   very well at the side. Curl's output can be piped into another program or
   redirected to another file for the next program to interpret.
 
-  We focus on protocol related issues and improvements. If you wanna do more
+  We focus on protocol related issues and improvements. If you want to do more
   magic with the supported protocols than curl currently does, chances are good
-  we will agree. If you wanna add more protocols, we may very well agree.
+  we will agree. If you want to add more protocols, we may very well agree.
 
   If you want someone else to do all the work while you wait for us to
   implement it for you, that is not a very friendly attitude. We spend a
index 54f1090b749624859bc54738951e1d0abc773fa9..effdcce217c3b68b4af5cb2d58a0423d4763a6df 100644 (file)
@@ -179,7 +179,7 @@ MAIL ETIQUETTE
   or just remove them completely from the mail. Note that this includes base64
   encoded HTTP Basic auth headers.
 
-  This public nature of the curl mailing lists makes automaticly inserted mail
+  This public nature of the curl mailing lists makes automatically inserted mail
   footers about mails being "private" or "only meant for the receipient" or
   similar even more silly than usual. Because they are absolutely not private
   when sent to a public mailing list.
index 59f0ec5439fd1e28884bb9ebb8505bd0bb6164af..f27de2d930966779df69d0194d9f692af25a6bf3 100644 (file)
@@ -8,5 +8,5 @@ standard, more informational, meter.
 This progress bar draws a single line of '#' characters across the screen and
 shows a percentage if the transfer size is known. For transfers without a
 known size, there will be space ship (-=o=-) that moves back and forth but
-only while data is being transfered, with a set of flying hash sign symbols on
+only while data is being transferred, with a set of flying hash sign symbols on
 top.
index 5fc41ef81df01213dbc62ece1d5a2446b3b26a9a..bd77bb1f3a60b2aa9747588b0a14c0311f5db4fb 100644 (file)
@@ -77,7 +77,7 @@ int main(void)
 
   /* get the file size of the local file */
   if(stat(LOCAL_FILE, &file_info)) {
-    printf("Couldnt open '%s': %s\n", LOCAL_FILE, strerror(errno));
+    printf("Couldn't open '%s': %s\n", LOCAL_FILE, strerror(errno));
     return 1;
   }
   fsize = (curl_off_t)file_info.st_size;
index ab2cbeb9934238c1c4e88e0ef2c0074847940f68..741e08e4ba170ed42de87dce0c8c6ab0b4096502 100644 (file)
@@ -856,7 +856,7 @@ discussed. Instead, the only way to have SSL work over a HTTP proxy is to ask
 the proxy to tunnel trough everything without being able to check or fiddle
 with the traffic.
 
-Opening an SSL connection over a HTTP proxy is therefor a matter of asking the
+Opening an SSL connection over a HTTP proxy is therefore a matter of asking the
 proxy for a straight connection to the target host on a specified port. This
 is made with the HTTP request CONNECT. ("please mr proxy, connect me to that
 remote host").
index 848d297082627afd6d2bb32eb69de690a2e0105f..a8d6fc2c6abaf480c2121f021819dcc4dd40b5ef 100644 (file)
@@ -31,7 +31,7 @@ CURLcode curl_easy_getinfo(CURL *handle, CURLINFO_CONDITION_UNMET, long *unmet);
 Pass a pointer to a long to receive the number 1 if the condition provided in
 the previous request didn't match (see \fICURLOPT_TIMECONDITION(3)\fP). Alas,
 if this returns a 1 you know that the reason you didn't get data in return is
-because it didn't fulfill the condition. The long ths argument points to will
+because it didn't fulfill the condition. The long this argument points to will
 get a zero stored if the condition instead was met.
 .SH PROTOCOLS
 HTTP and some
index bd106ae850d7d5d22bbf9edfe44a8fc9e0fe6bc3..b19dbaf79116be6d263fe548e4d660c4f9371a39 100644 (file)
@@ -186,8 +186,8 @@ CURL_EXTERN CURLMcode curl_multi_wait(CURLM *multi_handle,
   *
   * Returns: CURLMcode type, general multi error code. *NOTE* that this only
   *          returns errors etc regarding the whole multi stack. There might
-  *          still have occurred problems on invidual transfers even when this
-  *          returns OK.
+  *          still have occurred problems on individual transfers even when
+  *          this returns OK.
   */
 CURL_EXTERN CURLMcode curl_multi_perform(CURLM *multi_handle,
                                          int *running_handles);
index 92af9000c910a1369ed271e270971e8eec451963..c222bb87c005158f3bc8773d4d767a80193a8b40 100755 (executable)
@@ -26,7 +26,7 @@ my $indent = 2;
 
 my $warnings;
 my $errors;
-my $supressed; # whitelisted problems
+my $suppressed; # whitelisted problems
 my $file;
 my $dir=".";
 my $wlist;
@@ -60,7 +60,7 @@ my %warnings = (
     'ASTERISKNOSPACE'  => 'pointer declared without space before asterisk',
     'ASSIGNWITHINCONDITION'  => 'assignment within conditional expression',
     'EQUALSNOSPACE'    => 'equals sign without following space',
-    'NOSPACEEQUALS'    => 'equals sign without preceeding space',
+    'NOSPACEEQUALS'    => 'equals sign without preceding space',
     'SEMINOSPACE'      => 'semicolon without following space',
     'MULTISPACE'       => 'multiple spaces used when not suitable',
     );
@@ -101,7 +101,7 @@ sub checkwarn {
     }
 
     if($nowarn) {
-        $supressed++;
+        $suppressed++;
         if($w) {
             $swarnings++;
         }
@@ -422,7 +422,7 @@ sub scanfile {
                 # There is a quote here, figure out whether the comma is
                 # within a string or '' or not.
                 if($pref =~ /\"/) {
-                    # withing a string
+                    # within a string
                 }
                 elsif($pref =~ /\'$/) {
                     # a single letter
@@ -596,7 +596,7 @@ sub scanfile {
 
 if($errors || $warnings || $verbose) {
     printf "checksrc: %d errors and %d warnings\n", $errors, $warnings;
-    if($supressed) {
+    if($suppressed) {
         printf "checksrc: %d errors and %d warnings suppressed\n",
         $serrors,
         $swarnings;
index 03f47a3a52e384792ea98d9576e9a821e0b0d159..353a6564581ef459dfe74055e63ef5705e44dff2 100644 (file)
@@ -364,7 +364,7 @@ CURLcode Curl_output_ntlm_wb(struct connectdata *conn,
   case NTLMSTATE_TYPE1:
   default:
     /* Use Samba's 'winbind' daemon to support NTLM authentication,
-     * by delegating the NTLM challenge/response protocal to a helper
+     * by delegating the NTLM challenge/response protocol to a helper
      * in ntlm_auth.
      * http://devel.squid-cache.org/ntlm/squid_helper_protocol.html
      * https://www.samba.org/samba/docs/man/manpages-3/winbindd.8.html
index a119fe1b89835d2bc42424b8f5d47f055f94ebb7..fec5919187642a4bee6a17f978ec700d1b355b23 100644 (file)
--- a/lib/url.c
+++ b/lib/url.c
@@ -4117,7 +4117,7 @@ static CURLcode create_conn(struct Curl_easy *data,
    *************************************************************/
   if(prot_missing) {
     /* We're guessing prefixes here and if we're told to use a proxy or if
-       we're gonna follow a Location: later or... then we need the protocol
+       we're going to follow a Location: later or... then we need the protocol
        part added so that we have a valid URL. */
     char *reurl;
     char *ch_lower;
index 975333867c925e4e0f0dc6ac841a80180c35e1e4..3d7b9e5a53881afd7b5a0e7d0dc4c9615138f68a 100644 (file)
@@ -1166,7 +1166,7 @@ struct Curl_http2_dep {
 };
 
 /*
- * This struct is for holding data that was attemped to get sent to the user's
+ * This struct is for holding data that was attempted to get sent to the user's
  * callback but is held due to pausing. One instance per type (BOTH, HEADER,
  * BODY).
  */
index f9817b4e03976f15a8a2d1bfdd28d8e745a38c1c..c766a1f6e837cf665bd809e0360a54406f411ce9 100644 (file)
@@ -183,8 +183,8 @@ CCSID.
         CURLINFO_COOKIELIST
 Lists returned should be released with curl_slist_free_all() after use.
   Option CURLINFO_CERTINFO is followed by a struct curl_certinfo * * and a
-CCSID. Returned structures sould be free'ed using curl_certinfo_free_all() after
-use.
+CCSID. Returned structures should be free'ed using curl_certinfo_free_all()
+after use.
   Other options are processed like in curl_easy_getinfo().
 
 _ curl_pushheader_bynum_cssid() and curl_pushheader_byname_ccsid()
@@ -243,7 +243,7 @@ _ If data compression has to be supported, ZLIB development environment must
 _ Likewise, if SCP and SFTP protocols have to be compiled in, LIBSSH2
   developent environment must be installed.
 _ Install the curl source directory in IFS. Do NOT install it in the
-  installation target directory (wich defaults to /curl).
+  installation target directory (which defaults to /curl).
 _ Enter shell (QSH)
 _ Change current directory to the curl installation directory
 _ Change current directory to ./packages/OS400
index 2a5503f765b6abe1875c64215ff717f1ac4852ec..0f1fa0f6214bb39d4ac8cbbc8929fcba3dc1fa89 100644 (file)
@@ -1382,7 +1382,7 @@ $!                        search/out 'tfile1' "$_''keyterm'"
 $                      severity = '$severity'
 $                  endif
 $!
-$!                 Unix compatability routines
+$!                 Unix compatibility routines
 $!---------------------------------------------
 $                  if severity .ne. 1
 $                  then
index a927da592ae5f0fe5bf4d7c26fb58890dbbf7ab1..ebe6500ebbbfc41a5dfc017ae3cbe295ea36f106 100644 (file)
@@ -106,7 +106,7 @@ DESCR       = curl $(LIBCURL_VERSION_STR) ($(LIBARCH)) - https://curl.haxx.se
 MTSAFE = YES
 STACK  = 64000
 SCREEN = $(TARGET) commandline utility
-# Comment the line below if you dont want to load protected automatically.
+# Comment the line below if you don't want to load protected automatically.
 # LDRING = 3
 
 # Uncomment the next line to enable linking with POSIX semantics.
@@ -178,7 +178,7 @@ endif
        CFLAGS += -align 4
 else
        # PRELUDE = $(NDK_CLIB)/imports/clibpre.o
-       # to avoid the __init_* / __deinit_* whoes dont use prelude from NDK
+       # to avoid the __init_* / __deinit_* whoes don't use prelude from NDK
        PRELUDE = "$(MWCW_PATH)/libraries/runtime/prelude.obj"
        # CFLAGS += -include "$(MWCW_PATH)/headers/nlm_clib_prefix.h"
        CFLAGS += -align 1
@@ -201,7 +201,7 @@ else
 endif
 else
        # PRELUDE = $(NDK_CLIB)/imports/clibpre.gcc.o
-       # to avoid the __init_* / __deinit_* whoes dont use prelude from NDK
+       # to avoid the __init_* / __deinit_* whoes don't use prelude from NDK
        # http://www.gknw.net/development/mk_nlm/gcc_pre.zip
        PRELUDE = $(NDK_ROOT)/pre/prelude.o
        CFLAGS += -include $(NDKBASE)/nlmconv/genlm.h
index f7f4fa2ae389a7f2b12b23f5e149a46b87f891e7..97f7b8ea5ead66da8636927968b98f1b48144e10 100755 (executable)
@@ -2708,7 +2708,7 @@ sub datasockf_state {
 }
 
 #**********************************************************************
-# nodataconn_str returns string of efective nodataconn command. Notice
+# nodataconn_str returns string of effective nodataconn command. Notice
 # that $nodataconn may be set alone or in addition to a $nodataconnXXX.
 #
 sub nodataconn_str {
@@ -2934,7 +2934,7 @@ while(@ARGV) {
 }
 
 #***************************************************************************
-# Initialize command line option dependant variables
+# Initialize command line option dependent variables
 #
 
 if(!$srcdir) {
index 0093ea113c0ddaad7a5b9182d246cc6acaa2a09d..16045e6da4c1d7d1fdd89068fa156a3e928611be 100644 (file)
@@ -31,7 +31,7 @@
  * Simply download a HTTPS file!
  *
  * This test was added after the HTTPS-using-multi-interface with OpenSSL
- * regression of 7.19.1 to hopefully prevent this embarassing mistake from
+ * regression of 7.19.1 to hopefully prevent this embarrassing mistake from
  * appearing again... Unfortunately the bug wasn't triggered by this test,
  * which presumably is because the connect to a local server is too
  * fast/different compared to the real/distant servers we saw the bug happen
index fbb1cdee2f02ba9401c397832e242c3456767e1a..9771cf57f88103532d52d76f8e07369034be18ad 100755 (executable)
@@ -71,7 +71,7 @@ struct data {
 /* Unexpected error.
     CURLE_NOT_BUILT_IN   - means disabled at build
     CURLE_UNKNOWN_OPTION - means no such option (anymore?)
-    CURLE_SSL_ENGINE_NOTFOUND - set unkown ssl engine
+    CURLE_SSL_ENGINE_NOTFOUND - set unknown ssl engine
     CURLE_UNSUPPORTED_PROTOCOL - set bad HTTP version
     CURLE_BAD_FUNCTION_ARGUMENT - unsupported value
    */
index 393068cd35b9363ff7838c127ef456bb549135eb..6121d4c8e6849def93cc32416af00b54a84c95c6 100755 (executable)
@@ -69,7 +69,7 @@ sub file {
             if($str =~ /((libcurl|curl)([^ ]*))\(3\)/i) {
                 my $man = "$1.3";
                 if(!manpresent($man)) {
-                    print STDERR "error: $f:$line: refering to non-existing man page $man\n";
+                    print STDERR "error: $f:$line: referring to non-existing man page $man\n";
                     $errors++;
                 }
                 if($pre ne "I") {
@@ -87,7 +87,7 @@ sub file {
             while($i =~ s/((lib|)curl([^ ]*)) *\"\(3\)(,|) *\" *//i ) {
                 my $man = "$1.3";
                 if(!manpresent($man)) {
-                    print STDERR "error: $f:$line: refering to non-existing man page $man\n";
+                    print STDERR "error: $f:$line: referring to non-existing man page $man\n";
                     $errors++;
                 }
             }
index 10a87aaf990b9eb2cc98223ee6eb4796f26cd9d5..bd91c91bf10fcb2a14d1dc8676cb80ea045f21a3 100644 (file)
@@ -451,7 +451,7 @@ sub build_sys_abs_path {
         return $path;
     }
     elsif(should_use_cygpath()) {
-        # 'cygpath' is avalable - use it.
+        # 'cygpath' is available - use it.
 
         my $has_final_slash = ($path =~ m{[\\/]$});
 
index cfc1434cd7ba674bf7d25329ac499c78b685349c..73841027b54eca0e336b47473007be284840692a 100644 (file)
@@ -20,7 +20,7 @@ function(SETUP_EXECUTABLE TEST_NAME)    # ARGN are the files in the test
   target_link_libraries(${TEST_NAME} ${CURL_LIBS})
 
   # Test servers simply are standalone programs that do not use libcurl
-  # library.  For convinience and to ease portability of these servers,
+  # library.  For convenience and to ease portability of these servers,
   # some source code files from the libcurl subdirectory are also used
   # to build the servers.  In order to achieve proper linkage of these
   # files on Win32 targets it is necessary to build the test servers
index ceb04d8e8a5d2da91a58c299005f92e7828e9a69..40f5bdb480330f9f981e139dbb5781282711df9b 100644 (file)
@@ -1050,7 +1050,7 @@ static bool juggle(curl_socket_t *sockfdp,
 
        Commands:
 
-       DATA - plain pass-thru data
+       DATA - plain pass-through data
     */
 
     if(!read_stdin(buffer, 5))
index 1d47375ad638e657dbf990fc7d07ac5684c3cc1a..10a87746b3ba3f9431de478f639bb74ae2673d68 100644 (file)
@@ -1347,7 +1347,7 @@ static curl_socket_t connect_to(const char *ipaddr, unsigned short port)
   serverfd = socket(socket_domain, SOCK_STREAM, 0);
   if(CURL_SOCKET_BAD == serverfd) {
     error = SOCKERRNO;
-    logmsg("Error creating socket for server conection: (%d) %s",
+    logmsg("Error creating socket for server connection: (%d) %s",
            error, strerror(error));
     return CURL_SOCKET_BAD;
   }
@@ -1358,7 +1358,7 @@ static curl_socket_t connect_to(const char *ipaddr, unsigned short port)
     curl_socklen_t flag = 1;
     if(0 != setsockopt(serverfd, IPPROTO_TCP, TCP_NODELAY,
                        (void *)&flag, sizeof(flag)))
-      logmsg("====> TCP_NODELAY for server conection failed");
+      logmsg("====> TCP_NODELAY for server connection failed");
   }
 #endif
 
@@ -1423,7 +1423,7 @@ static curl_socket_t connect_to(const char *ipaddr, unsigned short port)
  * either end.
  *
  * When doing FTP through a CONNECT proxy, we expect that the data connection
- * will be setup while the first connect is still being kept up. Therefor we
+ * will be setup while the first connect is still being kept up. Therefore we
  * must accept a new connection and deal with it appropriately.
  */
 
@@ -1567,7 +1567,7 @@ static void http_connect(curl_socket_t *infdp,
             curl_socklen_t flag = 1;
             if(0 != setsockopt(datafd, IPPROTO_TCP, TCP_NODELAY,
                                (void *)&flag, sizeof(flag)))
-              logmsg("====> TCP_NODELAY for client DATA conection failed");
+              logmsg("====> TCP_NODELAY for client DATA connection failed");
           }
 #endif
           req2.pipelining = FALSE;
--- a/lib/ftp.c
+++ b/lib/ftp.c
@@ -1538,7 +1538,7 @@ static CURLcode ftp_state_type(struct connectdata *conn)
      date. */
   if(data->set.opt_no_body && ftpc->file &&
      ftp_need_type(conn, data->set.prefer_ascii)) {
/* The SIZE command is _not_ RFC 959 specified, and therefor many servers
        may not support it! It is however the only way we have to get a file's
        size! */
 
index a9b983e9bd61f9ca4e935f34f66315fd16e3ef2f..8da279268094cab7140cded8fd2067b8eedb89e4 100755 (executable)
@@ -314,7 +314,7 @@ Function RegExprFirst(SearchPattern, TheString)
   Set objRegExp = New RegExp                    ' create a regular expression.\r
   objRegExp.Pattern = SearchPattern             ' sets the search pattern.\r
   objRegExp.IgnoreCase = TRUE                   ' set to ignores case.\r
-  objRegExp.Global = TRUE                       ' set to gloabal search.\r
+  objRegExp.Global = TRUE                       ' set to global search.\r
   Set Matches = objRegExp.Execute(TheString)    ' do the search.\r
   If (Matches.Count) Then\r
     RegExprFirst = Matches(0).SubMatches(0)     ' return first match.\r
index 6a5b2a8378cb8deb71153988df4c1b07c8fba17d..e362f6e8e12bebf107a2933bdc2a874edf069ee3 100644 (file)
@@ -86,7 +86,7 @@ curl_10char_object_name() {
 # curl_8char_object_name
 #
 # Same as curl_10char_object_name() description and details above, except
-# that object name is limited to 8 charcters maximum.
+# that object name is limited to 8 characters maximum.
 #
 
 curl_8char_object_name() {
index 23a787fc969c4dbd7930f5c0eca7964008a612f4..aa27303fc00fb7187d52176d02799b84505bf868 100644 (file)
@@ -433,7 +433,7 @@ static int parsedate(const char *date, time_t *output)
           tzoff = (val/100 * 60 + val%100)*60;
 
           /* the + and - prefix indicates the local time compared to GMT,
-             this we need ther reversed math to get what we want */
+             this we need their reversed math to get what we want */
           tzoff = date[-1]=='+'?-tzoff:tzoff;
         }
 
index 168e24593ef117250555dca231c2698c2470a95d..c6069729070547e6e9c6cda51e339c46c553f7dd 100644 (file)
@@ -47,7 +47,7 @@
  *  -incoming server requests
  *      -server CSeq counter
  *  -digest authentication
- *  -connect thru proxy
+ *  -connect through proxy
  *  -pipelining?
  */
 
index 227d1fc6a476e36badf1611a82d5556728b651d7..27c0ccc730b24b206aedca25640fe48fbbc2a565 100644 (file)
@@ -389,7 +389,7 @@ ssize_t Curl_send_plain(struct connectdata *conn, int num,
       (WSAEWOULDBLOCK == err)
 #else
       /* errno may be EWOULDBLOCK or on some systems EAGAIN when it returned
-         due to its inability to send off data without blocking. We therefor
+         due to its inability to send off data without blocking. We therefore
          treat both error codes the same here */
       (EWOULDBLOCK == err) || (EAGAIN == err) || (EINTR == err) ||
       (EINPROGRESS == err)
@@ -456,7 +456,7 @@ ssize_t Curl_recv_plain(struct connectdata *conn, int num, char *buf,
       (WSAEWOULDBLOCK == err)
 #else
       /* errno may be EWOULDBLOCK or on some systems EAGAIN when it returned
-         due to its inability to send off data without blocking. We therefor
+         due to its inability to send off data without blocking. We therefore
          treat both error codes the same here */
       (EWOULDBLOCK == err) || (EAGAIN == err) || (EINTR == err)
 #endif
index c2acb52658888828d8741d592cd2abc21f9df835..55716c63b0ccb003096a5bbfea820735865af1e8 100644 (file)
@@ -242,7 +242,7 @@ static int SHA256_Final(unsigned char *out,
     sha256_compress(md, md->buf);
     md->curlen = 0;
   }
-  /* pad upto 56 bytes of zeroes */
+  /* pad up to 56 bytes of zeroes */
   while(md->curlen < 56) {
     md->buf[md->curlen++] = (unsigned char)0;
   }
index 48b134ee34c05518809093999f408c60b3e2fa93..78d3a853d071a4da22d9210a9ed46a7c63fcf9cf 100644 (file)
@@ -1460,7 +1460,8 @@ static CURLcode telnet_do(struct connectdata *conn, bool *done)
           if(n == 0)                        /* no bytes */
             break;
 
-          readfile_read = (DWORD)n; /* fall thru with number of bytes read */
+          /* fall through with number of bytes read */
+          readfile_read = (DWORD)n;
         }
         else {
           /* read from stdin */
@@ -1538,7 +1538,7 @@ static CURLcode ftp_state_type(struct connectdata *conn)
   if(data->set.opt_no_body && ftpc->file &&
      ftp_need_type(conn, data->set.prefer_ascii)) {
-    /* The SIZE command is _not_ RFC 959 specified, and therefor many servers
+    /* The SIZE command is _not_ RFC 959 specified, and therefore many servers
        may not support it! It is however the only way we have to get a file's
        size! */
index 90afd03a6645aeca5e720699a738f56a03bcdd73..f991ade5c313ade8bae9e25bbe71bf20d7169c34 100644 (file)